# Keycloak OIDC API Client

This is a (work in Progress) collection of client-side APIs to simplify the interaction with OGC API - Records - Part 1: Core.

## Installation

```
pip install ogc-api-records-core-client
```
